var EXPORTED_SYMBOLS = ["CreateContainer"];
Components.utils.import('resource://indexdata/runtime/Step.js');
Components.utils.import('resource://indexdata/runtime/StepError.js');
Components.utils.import('resource://indexdata/util/xulHelper.js');
Components.utils.import('resource://indexdata/util/jsonPathHelper.js');
var CreateContainer = function () { this.conf = {}; };
CreateContainer.prototype = new Step();
CreateContainer.prototype.constructor = CreateContainer;
CreateContainer.prototype.init = function(task) { };
CreateContainer.prototype.draw = function(surface) {
  xulHelper.jsonPathField(surface, this, this.conf, 'target', "Create at: ",
    null, { rwmode:"w", containermode:"anynode" } );
};
CreateContainer.prototype.run = function (task, block) {
  jsonPathHelper.set(this.conf.target, {}, task.data);
};
CreateContainer.prototype.getClassName = function () { return "CreateContainer"; };
CreateContainer.prototype.getDisplayName = function () { return "Create container"; };
CreateContainer.prototype.getDescription = function () {
  return "Create an object to contain a list of records";
};
CreateContainer.prototype.getVersion = function () { return "1.0"; };
CreateContainer.prototype.getUsedArgs = function () { return []; };
CreateContainer.prototype.renderArgs = function () {
  return this.conf.target ? this.conf.target.path + '/' + this.conf.target.key : "";
};
